==> pam_flutter-1.3.43.tar.gz: lib/repositories/consent_repository.dart <==
// ignore_for_file: non_constant_identifier_names

import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:http/http.dart';
import 'package:pam_flutter/models/contact_consent_model.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/types.dart';
import 'package:pam_flutter/utils/requester.dart';
import 'package:pam_flutter/utils/time_helper.dart';

class ConsentRepository extends BaseDataRepository<ContactConsentModel> {
  final BuildContext buildCtx;
  final IRepositoryOptions options;

  ConsentRepository({
    required this.buildCtx,
    required this.options,
  }) : super(buildCtx, options);

  @override
  Future<void> get(String id, {Map<String, dynamic>? params, bool isMock = false}) async {
    try {
      this.toLoadingStatus();
      late Map<String, dynamic> data;

      String? consentMessageId = params?["consent-message-id"];
      if(consentMessageId == null){
        throw("Consent message id must not empty");
      }

      if (params == null) {
        params = {};
      }

      if (isMock) {
        await TimeHelper.sleep();
        data = {"data": this.options.getMockItem()};
      } else {
        Response response = await Requester.get(
            "${this.options.getFindUrl() ?? this.options.getBaseUrl()}/$consentMessageId"
                .replaceFirst(":id", id),
            params);
        Map<String, dynamic> js = json.decode(utf8.decode(response.bodyBytes));
        print("response = ${js}");
        print("request = ${response.request?.url}");
        data = {"data": js};
      }

      super.setInnerData(data["data"]);
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.alertError(e);
      this.toErrorStatus(e);
    }
  }

  @override
  List<ContactConsentModel> transforms(tss) {
    return ContactConsentModel.toList(tss);
  }

  @override
  ContactConsentModel? transform(ts) {
    return ContactConsentModel.fromJson(ts);
  }
}

==> pam_flutter-1.4.57.tar.gz: lib/repositories/consent_repository.dart <==
// ignore_for_file: non_constant_identifier_names

import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:http/http.dart';
import 'package:pam_flutter/models/contact_consent_model.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/types.dart';
import 'package:pam_flutter/utils/requester.dart';
import 'package:pam_flutter/utils/time_helper.dart';

class ConsentRepository extends BaseDataRepository<ContactConsentModel> {
  final BuildContext buildCtx;
  final IRepositoryOptions options;

  ConsentRepository({
    required this.buildCtx,
    required this.options,
  }) : super(buildCtx, options);

  @override
  Future<void> get(String id,
      {Map<String, dynamic>? params, bool isMock = false}) async {
    try {
      this.toLoadingStatus();
      late Map<String, dynamic> data;

      String? consentMessageId = params?["consent-message-id"];
      if (consentMessageId == null) {
        throw ("Consent message id must not empty");
      }
      params?.remove("consent-message-id");

      if (params == null) {
        params = {};
      }

      if (isMock) {
        await TimeHelper.sleep();
        data = {"data": this.options.getMockItem()};
      } else {
        Response response = await Requester.get(
            "${this.options.getFindUrl() ?? this.options.getBaseUrl()}/$consentMessageId"
                .replaceFirst(":id", id),
            params);
        Map<String, dynamic> js = json.decode(utf8.decode(response.bodyBytes));
        data = {"data": js};
        print(data);
      }

      super.setInnerData(data["data"]);
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.alertError(e);
      this.toErrorStatus(e);
    }
  }

  @override
  List<ContactConsentModel> transforms(tss) {
    return ContactConsentModel.toList(tss);
  }

  @override
  ContactConsentModel? transform(ts) {
    return ContactConsentModel.fromJson(ts);
  }
}
